==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardParametersIntegerParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Display name for the dashboard.
 * @property values
 */
public data class DashboardParametersIntegerParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<Int>>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs =
        com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DashboardParametersIntegerParameterArgs].
 */
@PulumiTagMarker
public class DashboardParametersIntegerParameterArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<Int>>? = null

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("qysfesmmwgofeuik")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("lxisnxvclisdfpex")
    public suspend fun values(`value`: Output<List<Int>>) {
        this.values = value
    }

    @JvmName("xomuwnxxalveysqw")
    public suspend fun values(vararg values: Output<Int>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vcfutrochybatagp")
    public suspend fun values(values: List<Output<Int>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("sebfbbyopijvrvlr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("lqettvodubnsddas")
    public suspend fun values(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("flaqbeslnwhwiryb")
    public suspend fun values(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): DashboardParametersIntegerParameterArgs =
        DashboardParametersIntegerParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardParametersIntegerParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Display name for the dashboard.
 * @property values
 */
public data class DashboardParametersIntegerParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<Int>>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs =
        com.pulumi.aws.quicksight.inputs.DashboardParametersIntegerParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DashboardParametersIntegerParameterArgs].
 */
@PulumiTagMarker
public class DashboardParametersIntegerParameterArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<Int>>? = null

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("haklbgkllangnpgy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("mnlmfgyketsvhkah")
    public suspend fun values(`value`: Output<List<Int>>) {
        this.values = value
    }

    @JvmName("dpxevqlayeqfapft")
    public suspend fun values(vararg values: Output<Int>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("cpcbewrtvpsxqpus")
    public suspend fun values(values: List<Output<Int>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("hpnkjtndkftiwruo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("wwaohukvioepywqb")
    public suspend fun values(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("qwsroopvgwtqkkaj")
    public suspend fun values(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): DashboardParametersIntegerParameterArgs =
        DashboardParametersIntegerParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}
